==> applet-web-boot-starter-3.1.2-sources.jar: cn/sinozg/applet/common/filter/WrapperInputStream.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.common.filter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import jakarta.servlet.ReadListener;
import jakarta.servlet.ServletInputStream;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 * 请求 参数缓存 包装 类
 * @Author: xyb
 * @Description:
 * @Date: 2023-03-10 下午 11:52
 **/
public class WrapperInputStream extends ServletInputStream {

    private final InputStream cacheInputStream;

    private final Logger log = LoggerFactory.getLogger(WrapperInputStream.class);

    public WrapperInputStream(byte[] body){
        this.cacheInputStream = new ByteArrayInputStream(body);
    }

    @Override
    public boolean isFinished() {
        try {
            return cacheInputStream.available() == 0;
        } catch (Exception e) {
            log.error("缓存请求参数流 异常，{}", e.getMessage());
        }
        return false;
    }

    @Override
    public boolean isReady() {
        return true;
    }

    @Override
    public void setReadListener(ReadListener readListener) {
    }

    @Override
    public int read() throws IOException {
        return cacheInputStream.read();
    }
}

==> applet-web-boot-starter-3.2.3-sources.jar: cn/sinozg/applet/common/filter/WrapperInputStream.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.common.filter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import jakarta.servlet.ReadListener;
import jakarta.servlet.ServletInputStream;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 * 请求 参数缓存 包装 类
 * @Author: xyb
 * @Description:
 * @Date: 2023-03-10 下午 11:52
 **/
class WrapperInputStream extends ServletInputStream {

    private final InputStream cacheInputStream;

    private final Logger log = LoggerFactory.getLogger(WrapperInputStream.class);

    public WrapperInputStream(byte[] body){
        this.cacheInputStream = new ByteArrayInputStream(body);
    }

    @Override
    public boolean isFinished() {
        try {
            return cacheInputStream.available() == 0;
        } catch (Exception e) {
            log.error("缓存请求参数流 异常，{}", e.getMessage());
        }
        return false;
    }

    @Override
    public boolean isReady() {
        return true;
    }

    @Override
    public void setReadListener(ReadListener readListener) {
    }

    @Override
    public int read() throws IOException {
        return cacheInputStream.read();
    }
}
